import os
import pickle
from dataclasses import dataclass, asdict, field
from dacite import from_dict
import fire

data_path = os.path.expanduser("~//.filpick")


@dataclass
class Data:
    root_path: str = ""
    results: list = field(default_factory=list)


data = Data()
if os.path.exists(data_path):
    data = from_dict(data_class=Data, data=pickle.load(open(data_path, "rb")))


def set_root_path(path):
    data.root_path = path
    pickle.dump(asdict(data), open(data_path, "wb"))


def list():
    data.results = os.listdir(data.root_path)
    for i, file_name in enumerate(data.results):
        print(str(i)+" -> "+file_name)
    pickle.dump(asdict(data), open(data_path, "wb"))


def open_(index):
    file_name = data.results[index]
    os.chdir(data.root_path)
    os.system(f'"{file_name}"')


def main():
    fire.Fire({
        "set_root_path": set_root_path,
        "list": list,
        "open": open_
    })



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['filpick']

package_data = \
{'': ['*']}

install_requires = \
['dacite>=1.6.0,<2.0.0', 'fire>=0.4.0,<0.5.0']

entry_points = \
{'console_scripts': ['filpick = filpick:main']}

setup_kwargs = {
    'name': 'filpick',
    'version': '0.1.2',
    'description': '',
    'long_description': '',
    'author': 'aoout',
    'author_email': 'wuz66280@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
